@@ -1,12 +1,11 @@
 package Message::Passing::ZeroMQ;
 use strict;
 use warnings;
-use ZeroMQ qw/ :all /;
 use POSIX::AtFork ();
 use Sub::Name;
 use namespace::clean -except => 'meta';
 
-our $VERSION = "0.007";
+our $VERSION = "0.008";
 $VERSION = eval $VERSION;
 
 our @_WITH_CONTEXTS;
@@ -178,7 +177,7 @@ For more detailed information about ZeroMQ and how it works, please consult the
 
 =item L<Message::Passing>
 
-=item L<ZeroMQ>
+=item L<ZMQ::FFI>
 
 =item L<http://www.zeromq.org/>
 
